@@ -13,8 +13,15 @@
 # limitations under the License.
 from __future__ import absolute_import, division, print_function
 
-from nacl._sodium import lib
-from nacl.exceptions import CryptoError
+from nacl import exceptions as exc
+from nacl._sodium import ffi, lib
+from nacl.exceptions import ensure
+
+
+def _sodium_init():
+    ensure(lib.sodium_init() != -1,
+           "Could not initialize sodium",
+           raising=exc.RuntimeError)
 
 
 def sodium_init():
@@ -22,5 +29,4 @@ def sodium_init():
     Initializes sodium, picking the best implementations available for this
     machine.
     """
-    if lib.sodium_init() != 0:
-        raise CryptoError("Could not initialize sodium")
+    ffi.init_once(_sodium_init, "libsodium")
